@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2018-06-10'; # DATE
-our $VERSION = '0.140'; # VERSION
+our $DATE = '2018-06-11'; # DATE
+our $VERSION = '0.141'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,7 +58,7 @@ sub _add_prereqs_from_func_meta {
     {
         require Perinci::Sub::Util::DepModule;
         my $mods = Perinci::Sub::Util::DepModule::get_required_dep_modules($meta);
-        $self->_add_prereq($_ => $mods->{$_}) for keys %$mods;
+        $self->_add_prereq($_ => $mods->{$_} // 0) for keys %$mods;
     }
 
     {
@@ -217,7 +217,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.140 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2018-06-10.
+This document describes version 0.141 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2018-06-11.
 
 =head1 SYNOPSIS
 
